==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ProxySpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ProxySpecFluentImpl<A extends io.fabric8.openshift.api.model.ProxySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ProxySpecFluent<A>{
  public ProxySpecFluentImpl() {
  }
  public ProxySpecFluentImpl(io.fabric8.openshift.api.model.ProxySpec instance) {
    this.withHttpProxy(instance.getHttpProxy()); 
    this.withHttpsProxy(instance.getHttpsProxy()); 
    this.withNoProxy(instance.getNoProxy()); 
    this.withReadinessEndpoints(instance.getReadinessEndpoints()); 
    this.withTrustedCA(instance.getTrustedCA()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String httpProxy;
  private java.lang.String httpsProxy;
  private java.lang.String noProxy;
  private java.util.List<java.lang.String> readinessEndpoints = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder trustedCA;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHttpProxy() {
    return this.httpProxy;
  }
  public A withHttpProxy(java.lang.String httpProxy) {
    this.httpProxy=httpProxy; return (A) this;
  }
  public java.lang.Boolean hasHttpProxy() {
    return this.httpProxy != null;
  }
  
  /**
   * Method is deprecated. use withHttpProxy instead.
   */
  @java.lang.Deprecated
  public A withNewHttpProxy(java.lang.String arg0) {
    return (A)withHttpProxy(new String(arg0));
  }
  public java.lang.String getHttpsProxy() {
    return this.httpsProxy;
  }
  public A withHttpsProxy(java.lang.String httpsProxy) {
    this.httpsProxy=httpsProxy; return (A) this;
  }
  public java.lang.Boolean hasHttpsProxy() {
    return this.httpsProxy != null;
  }
  
  /**
   * Method is deprecated. use withHttpsProxy instead.
   */
  @java.lang.Deprecated
  public A withNewHttpsProxy(java.lang.String arg0) {
    return (A)withHttpsProxy(new String(arg0));
  }
  public java.lang.String getNoProxy() {
    return this.noProxy;
  }
  public A withNoProxy(java.lang.String noProxy) {
    this.noProxy=noProxy; return (A) this;
  }
  public java.lang.Boolean hasNoProxy() {
    return this.noProxy != null;
  }
  
  /**
   * Method is deprecated. use withNoProxy instead.
   */
  @java.lang.Deprecated
  public A withNewNoProxy(java.lang.String arg0) {
    return (A)withNoProxy(new String(arg0));
  }
  public A addToReadinessEndpoints(java.lang.Integer index,java.lang.String item) {
    if (this.readinessEndpoints == null) {this.readinessEndpoints = new java.util.ArrayList<java.lang.String>();}
    this.readinessEndpoints.add(index, item);
    return (A)this;
  }
  public A setToReadinessEndpoints(java.lang.Integer index,java.lang.String item) {
    if (this.readinessEndpoints == null) {this.readinessEndpoints = new java.util.ArrayList<java.lang.String>();}
    this.readinessEndpoints.set(index, item); return (A)this;
  }
  public A addToReadinessEndpoints(java.lang.String... items) {
    if (this.readinessEndpoints == null) {this.readinessEndpoints = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.readinessEndpoints.add(item);} return (A)this;
  }
  public A addAllToReadinessEndpoints(java.util.Collection<java.lang.String> items) {
    if (this.readinessEndpoints == null) {this.readinessEndpoints = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.readinessEndpoints.add(item);} return (A)this;
  }
  public A removeFromReadinessEndpoints(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.readinessEndpoints!= null){ this.readinessEndpoints.remove(item);}} return (A)this;
  }
  public A removeAllFromReadinessEndpoints(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.readinessEndpoints!= null){ this.readinessEndpoints.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getReadinessEndpoints() {
    return this.readinessEndpoints;
  }
  public java.lang.String getReadinessEndpoint(java.lang.Integer index) {
    return this.readinessEndpoints.get(index);
  }
  public java.lang.String getFirstReadinessEndpoint() {
    return this.readinessEndpoints.get(0);
  }
  public java.lang.String getLastReadinessEndpoint() {
    return this.readinessEndpoints.get(readinessEndpoints.size() - 1);
  }
  public java.lang.String getMatchingReadinessEndpoint(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: readinessEndpoints) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingReadinessEndpoint(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: readinessEndpoints) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withReadinessEndpoints(java.util.List<java.lang.String> readinessEndpoints) {
    if (readinessEndpoints != null) {this.readinessEndpoints = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : readinessEndpoints){this.addToReadinessEndpoints(item);}} else { this.readinessEndpoints = null;} return (A) this;
  }
  public A withReadinessEndpoints(java.lang.String... readinessEndpoints) {
    if (this.readinessEndpoints != null) {this.readinessEndpoints.clear();}
    if (readinessEndpoints != null) {for (java.lang.String item :readinessEndpoints){ this.addToReadinessEndpoints(item);}} return (A) this;
  }
  public java.lang.Boolean hasReadinessEndpoints() {
    return readinessEndpoints != null && !readinessEndpoints.isEmpty();
  }
  public A addNewReadinessEndpoint(java.lang.String arg0) {
    return (A)addToReadinessEndpoints(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTrustedCA instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getTrustedCA() {
    return this.trustedCA!=null?this.trustedCA.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildTrustedCA() {
    return this.trustedCA!=null?this.trustedCA.build():null;
  }
  public A withTrustedCA(io.fabric8.openshift.api.model.ConfigMapNameReference trustedCA) {
    _visitables.get("trustedCA").remove(this.trustedCA);
    if (trustedCA!=null){ this.trustedCA= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(trustedCA); _visitables.get("trustedCA").add(this.trustedCA);} return (A) this;
  }
  public java.lang.Boolean hasTrustedCA() {
    return this.trustedCA != null;
  }
  public A withNewTrustedCA(java.lang.String name) {
    return (A)withTrustedCA(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> withNewTrustedCA() {
    return new io.fabric8.openshift.api.model.ProxySpecFluentImpl.TrustedCANestedImpl();
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> withNewTrustedCALike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.ProxySpecFluentImpl.TrustedCANestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> editTrustedCA() {
    return withNewTrustedCALike(getTrustedCA());
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> editOrNewTrustedCA() {
    return withNewTrustedCALike(getTrustedCA() != null ? getTrustedCA(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> editOrNewTrustedCALike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewTrustedCALike(getTrustedCA() != null ? getTrustedCA(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProxySpecFluentImpl that = (ProxySpecFluentImpl) o;
    if (httpProxy != null ? !httpProxy.equals(that.httpProxy) :that.httpProxy != null) return false;
    if (httpsProxy != null ? !httpsProxy.equals(that.httpsProxy) :that.httpsProxy != null) return false;
    if (noProxy != null ? !noProxy.equals(that.noProxy) :that.noProxy != null) return false;
    if (readinessEndpoints != null ? !readinessEndpoints.equals(that.readinessEndpoints) :that.readinessEndpoints != null) return false;
    if (trustedCA != null ? !trustedCA.equals(that.trustedCA) :that.trustedCA != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpProxy,  httpsProxy,  noProxy,  readinessEndpoints,  trustedCA,  additionalProperties,  super.hashCode());
  }
  public class TrustedCANestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<N>> implements io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TrustedCANestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    TrustedCANestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) ProxySpecFluentImpl.this.withTrustedCA(builder.build());
    }
    public N endTrustedCA() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ProxySpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ProxySpecFluentImpl<A extends io.fabric8.openshift.api.model.ProxySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ProxySpecFluent<A>{
  public ProxySpecFluentImpl() {
  }
  public ProxySpecFluentImpl(io.fabric8.openshift.api.model.ProxySpec instance) {
    this.withHttpProxy(instance.getHttpProxy()); 
    this.withHttpsProxy(instance.getHttpsProxy()); 
    this.withNoProxy(instance.getNoProxy()); 
    this.withReadinessEndpoints(instance.getReadinessEndpoints()); 
    this.withTrustedCA(instance.getTrustedCA()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String httpProxy;
  private java.lang.String httpsProxy;
  private java.lang.String noProxy;
  private java.util.List<java.lang.String> readinessEndpoints = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder trustedCA;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHttpProxy() {
    return this.httpProxy;
  }
  public A withHttpProxy(java.lang.String httpProxy) {
    this.httpProxy=httpProxy; return (A) this;
  }
  public java.lang.Boolean hasHttpProxy() {
    return this.httpProxy != null;
  }
  
  /**
   * Method is deprecated. use withHttpProxy instead.
   */
  @java.lang.Deprecated
  public A withNewHttpProxy(java.lang.String arg0) {
    return (A)withHttpProxy(new String(arg0));
  }
  public java.lang.String getHttpsProxy() {
    return this.httpsProxy;
  }
  public A withHttpsProxy(java.lang.String httpsProxy) {
    this.httpsProxy=httpsProxy; return (A) this;
  }
  public java.lang.Boolean hasHttpsProxy() {
    return this.httpsProxy != null;
  }
  
  /**
   * Method is deprecated. use withHttpsProxy instead.
   */
  @java.lang.Deprecated
  public A withNewHttpsProxy(java.lang.String arg0) {
    return (A)withHttpsProxy(new String(arg0));
  }
  public java.lang.String getNoProxy() {
    return this.noProxy;
  }
  public A withNoProxy(java.lang.String noProxy) {
    this.noProxy=noProxy; return (A) this;
  }
  public java.lang.Boolean hasNoProxy() {
    return this.noProxy != null;
  }
  
  /**
   * Method is deprecated. use withNoProxy instead.
   */
  @java.lang.Deprecated
  public A withNewNoProxy(java.lang.String arg0) {
    return (A)withNoProxy(new String(arg0));
  }
  public A addToReadinessEndpoints(java.lang.Integer index,java.lang.String item) {
    if (this.readinessEndpoints == null) {this.readinessEndpoints = new java.util.ArrayList<java.lang.String>();}
    this.readinessEndpoints.add(index, item);
    return (A)this;
  }
  public A setToReadinessEndpoints(java.lang.Integer index,java.lang.String item) {
    if (this.readinessEndpoints == null) {this.readinessEndpoints = new java.util.ArrayList<java.lang.String>();}
    this.readinessEndpoints.set(index, item); return (A)this;
  }
  public A addToReadinessEndpoints(java.lang.String... items) {
    if (this.readinessEndpoints == null) {this.readinessEndpoints = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.readinessEndpoints.add(item);} return (A)this;
  }
  public A addAllToReadinessEndpoints(java.util.Collection<java.lang.String> items) {
    if (this.readinessEndpoints == null) {this.readinessEndpoints = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.readinessEndpoints.add(item);} return (A)this;
  }
  public A removeFromReadinessEndpoints(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.readinessEndpoints!= null){ this.readinessEndpoints.remove(item);}} return (A)this;
  }
  public A removeAllFromReadinessEndpoints(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.readinessEndpoints!= null){ this.readinessEndpoints.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getReadinessEndpoints() {
    return this.readinessEndpoints;
  }
  public java.lang.String getReadinessEndpoint(java.lang.Integer index) {
    return this.readinessEndpoints.get(index);
  }
  public java.lang.String getFirstReadinessEndpoint() {
    return this.readinessEndpoints.get(0);
  }
  public java.lang.String getLastReadinessEndpoint() {
    return this.readinessEndpoints.get(readinessEndpoints.size() - 1);
  }
  public java.lang.String getMatchingReadinessEndpoint(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: readinessEndpoints) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingReadinessEndpoint(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: readinessEndpoints) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withReadinessEndpoints(java.util.List<java.lang.String> readinessEndpoints) {
    if (readinessEndpoints != null) {this.readinessEndpoints = new java.util.ArrayList(); for (java.lang.String item : readinessEndpoints){this.addToReadinessEndpoints(item);}} else { this.readinessEndpoints = null;} return (A) this;
  }
  public A withReadinessEndpoints(java.lang.String... readinessEndpoints) {
    if (this.readinessEndpoints != null) {this.readinessEndpoints.clear();}
    if (readinessEndpoints != null) {for (java.lang.String item :readinessEndpoints){ this.addToReadinessEndpoints(item);}} return (A) this;
  }
  public java.lang.Boolean hasReadinessEndpoints() {
    return readinessEndpoints != null && !readinessEndpoints.isEmpty();
  }
  public A addNewReadinessEndpoint(java.lang.String arg0) {
    return (A)addToReadinessEndpoints(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTrustedCA instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getTrustedCA() {
    return this.trustedCA!=null?this.trustedCA.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildTrustedCA() {
    return this.trustedCA!=null?this.trustedCA.build():null;
  }
  public A withTrustedCA(io.fabric8.openshift.api.model.ConfigMapNameReference trustedCA) {
    _visitables.get("trustedCA").remove(this.trustedCA);
    if (trustedCA!=null){ this.trustedCA= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(trustedCA); _visitables.get("trustedCA").add(this.trustedCA);} return (A) this;
  }
  public java.lang.Boolean hasTrustedCA() {
    return this.trustedCA != null;
  }
  public A withNewTrustedCA(java.lang.String name) {
    return (A)withTrustedCA(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> withNewTrustedCA() {
    return new io.fabric8.openshift.api.model.ProxySpecFluentImpl.TrustedCANestedImpl();
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> withNewTrustedCALike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.ProxySpecFluentImpl.TrustedCANestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> editTrustedCA() {
    return withNewTrustedCALike(getTrustedCA());
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> editOrNewTrustedCA() {
    return withNewTrustedCALike(getTrustedCA() != null ? getTrustedCA(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<A> editOrNewTrustedCALike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewTrustedCALike(getTrustedCA() != null ? getTrustedCA(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProxySpecFluentImpl that = (ProxySpecFluentImpl) o;
    if (httpProxy != null ? !httpProxy.equals(that.httpProxy) :that.httpProxy != null) return false;
    if (httpsProxy != null ? !httpsProxy.equals(that.httpsProxy) :that.httpsProxy != null) return false;
    if (noProxy != null ? !noProxy.equals(that.noProxy) :that.noProxy != null) return false;
    if (readinessEndpoints != null ? !readinessEndpoints.equals(that.readinessEndpoints) :that.readinessEndpoints != null) return false;
    if (trustedCA != null ? !trustedCA.equals(that.trustedCA) :that.trustedCA != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpProxy,  httpsProxy,  noProxy,  readinessEndpoints,  trustedCA,  additionalProperties,  super.hashCode());
  }
  public class TrustedCANestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<N>> implements io.fabric8.openshift.api.model.ProxySpecFluent.TrustedCANested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TrustedCANestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    TrustedCANestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) ProxySpecFluentImpl.this.withTrustedCA(builder.build());
    }
    public N endTrustedCA() {
      return and();
    }
    
  }
  
}
